## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>", crop = NULL)

## ----vignetteSetup, echo=FALSE, message=FALSE, warning = FALSE----------------
startTime <- Sys.time()
library("RefManageR")
bib <- c(
    R = citation(),
    BiocStyle = citation("BiocStyle")[1],
    SummarizedExperiment = citation("SummarizedExperiment")[1],
    knitr = citation("knitr")[1],
    RefManageR = citation("RefManageR")[1],
    rmarkdown = citation("rmarkdown")[1],
    sessioninfo = citation("sessioninfo")[1],
    testthat = citation("testthat")[1],
    mlbench = citation("mlbench")[1],
    TCMC = citation("TCMC")[1]
)

## ----"install", eval = FALSE--------------------------------------------------
# if (!requireNamespace("BiocManager", quietly = TRUE)) {
#     install.packages("BiocManager")
# }
# BiocManager::install("TCMC")
# BiocManager::valid()

## ----"citation"---------------------------------------------------------------
citation("TCMC")

## ----"start", message=FALSE, warning=FALSE------------------------------------
library(TCMC)
library(mlbench)

## ----data---------------------------------------------------------------------
data(PimaIndiansDiabetes)
str(PimaIndiansDiabetes)

## ----model, message=FALSE, warning=FALSE--------------------------------------
# for this example only LVQ and GBM are being tested
results <- model_comparer(PimaIndiansDiabetes, "diabetes", for_utest = TRUE)

## ----plot_vip-----------------------------------------------------------------
# plot variable importance for a specific model
plot_importance(results$trained_models$lvq, "LVQ")
plot_importance(results$trained_models$rf, "RF")

## ----assess-------------------------------------------------------------------
# access trained models
models_results <- resamples(results$trained_models)
summary(models_results)

## ----plot_acc-----------------------------------------------------------------
bwplot(models_results)

## ----best_model---------------------------------------------------------------
best_model <- results$performance$rf
best_model

## ----initial_class, warning=FALSE, message=FALSE------------------------------
library(SummarizedExperiment)

# Simulate data
nrows <- 200 # Number of features (e.g., genes or biomarkers)
ncols <- 8  # Number of samples
sugar_level <- matrix(runif(nrows * ncols, 1, 500), nrows)

# Metadata: treatment classes and outcomes
colData <- DataFrame(Treatment_class = rep(c("TZD", "DPP-4"), 4),
        row.names = LETTERS[1:8])
Outcome <- DataFrame(Outcome = (rep(c("neg", "pos"), 5)))
se0 <- SummarizedExperiment(assays = SimpleList(counts = sugar_level),
        colData = colData, metadata = Outcome)

## ----formatting---------------------------------------------------------------
# in the case the input is a SummarizedExperiment, extract assay and metadata
if (inherits(se0, "SummarizedExperiment")) {
    data <- as.data.frame(assay(se0))
    metadata <- as.data.frame(metadata(se0))
    data_df <- cbind(metadata, data)
}
feature_names <- c("Outcome",
    "TreatmentA", "TreatmentB", "TreatmentC", "TreatmentD", 
    "TreatmentE", "TreatmentF", "TreatmentG", "TreatmentH"
)
colnames(data_df) <- feature_names
data_df$Outcome <- data_df$Outcome |> as.factor()
str(data_df) 


## ----results_outcome, warning=FALSE-------------------------------------------
results <- model_comparer(data = data_df, "Outcome", for_utest = TRUE)

## ----plot_vis_outcome---------------------------------------------------------
plot_importance(results$trained_models$lvq, "LVQ", type_plot = "enhanced")
plot_importance(results$trained_models$rf, "RF", type_plot = "basic")

models_results <- resamples(results$trained_models)
summary(models_results)

bwplot(models_results)

best_model <- results$performance$rf
best_model

## ----reproduce1, echo=FALSE---------------------------------------------------
Sys.time()

## ----reproduce2, echo=FALSE---------------------------------------------------
totalTime <- diff(c(startTime, Sys.time()))
round(totalTime, digits = 3)

## ----reproduce3, echo=FALSE-------------------------------------------------------------------------------------------
library("sessioninfo")
options(width = 120)
session_info()

## ----vignetteBiblio, results = "asis", echo = FALSE, warning = FALSE--------------------------------------------------
PrintBibliography(bib, .opts = list(hyperlink = "to.doc", style = "html"))

